@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,16 +52,17 @@
 
 package org.mariadb.jdbc;
 
-import org.mariadb.jdbc.internal.*;
-import org.mariadb.jdbc.internal.com.read.resultset.*;
-import org.mariadb.jdbc.internal.util.exceptions.*;
-
-import java.io.*;
-import java.math.*;
-import java.net.*;
-import java.sql.Date;
+import java.io.InputStream;
+import java.io.Reader;
+import java.math.BigDecimal;
+import java.net.URL;
 import java.sql.*;
-import java.util.*;
+import java.util.Calendar;
+import java.util.List;
+import java.util.Map;
+import org.mariadb.jdbc.internal.ColumnType;
+import org.mariadb.jdbc.internal.com.read.resultset.SelectResultSet;
+import org.mariadb.jdbc.internal.util.exceptions.ExceptionFactory;
 
 public abstract class CallableProcedureStatement extends ServerSidePreparedStatement
     implements CallableStatement, Cloneable {
@@ -72,6 +73,8 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
   protected int[] outputParameterMapper = null;
   protected CallableParameterMetaData parameterMetadata;
   protected boolean hasInOutParameters;
+  private String database;
+  private String procedureName;
 
   /**
    * Constructor for getter/setter of callableStatement.
@@ -83,12 +86,29 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
    *     <code>ResultSet.TYPE_SCROLL_SENSITIVE</code>
    * @param resultSetConcurrency a concurrency type; one of <code>ResultSet.CONCUR_READ_ONLY</code>
    *     or <code>ResultSet.CONCUR_UPDATABLE</code>
+   * @param exceptionFactory Exception factory
+   * @param database database name
+   * @param procedureName function name
    * @throws SQLException is prepareStatement connection throw any error
    */
   public CallableProcedureStatement(
-      MariaDbConnection connection, String sql, int resultSetScrollType, int resultSetConcurrency)
+      MariaDbConnection connection,
+      String sql,
+      int resultSetScrollType,
+      int resultSetConcurrency,
+      ExceptionFactory exceptionFactory,
+      String database,
+      String procedureName)
       throws SQLException {
-    super(connection, sql, resultSetScrollType, resultSetConcurrency, Statement.NO_GENERATED_KEYS);
+    super(
+        connection,
+        sql,
+        resultSetScrollType,
+        resultSetConcurrency,
+        Statement.NO_GENERATED_KEYS,
+        exceptionFactory);
+    this.database = database;
+    this.procedureName = procedureName;
   }
 
   /**
@@ -122,10 +142,16 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
   protected abstract SelectResultSet getOutputResult() throws SQLException;
 
   public ParameterMetaData getParameterMetaData() throws SQLException {
-    parameterMetadata.readMetadataFromDbIfRequired();
+    readMetadataFromDbIfRequired();
     return parameterMetadata;
   }
 
+  private void readMetadataFromDbIfRequired() throws SQLException {
+    if (parameterMetadata == null) {
+      parameterMetadata = connection.getInternalParameterMetaData(procedureName, database, false);
+    }
+  }
+
   /**
    * Convert parameter name to parameter index in the query.
    *
@@ -134,9 +160,9 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
    * @throws SQLException exception
    */
   private int nameToIndex(String parameterName) throws SQLException {
-    parameterMetadata.readMetadataFromDbIfRequired();
+    readMetadataFromDbIfRequired();
     for (int i = 1; i <= parameterMetadata.getParameterCount(); i++) {
-      String name = parameterMetadata.getName(i);
+      String name = parameterMetadata.getParameterName(i);
       if (name != null && name.equalsIgnoreCase(parameterName)) {
         return i;
       }
@@ -152,9 +178,9 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
    * @throws SQLException exception
    */
   private int nameToOutputIndex(String parameterName) throws SQLException {
-    parameterMetadata.readMetadataFromDbIfRequired();
+    readMetadataFromDbIfRequired();
     for (int i = 0; i < parameterMetadata.getParameterCount(); i++) {
-      String name = parameterMetadata.getName(i + 1);
+      String name = parameterMetadata.getParameterName(i + 1);
       if (name != null && name.equalsIgnoreCase(parameterName)) {
         if (outputParameterMapper[i] == -1) {
           // this is not an outputParameter
@@ -324,7 +350,7 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
 
   @Override
   public Date getDate(int parameterIndex, Calendar cal) throws SQLException {
-    return getOutputResult().getDate(parameterIndex, cal);
+    return getOutputResult().getDate(indexToOutputIndex(parameterIndex), cal);
   }
 
   @Override
@@ -349,7 +375,7 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
 
   @Override
   public Timestamp getTimestamp(int parameterIndex) throws SQLException {
-    return getOutputResult().getTimestamp(parameterIndex);
+    return getOutputResult().getTimestamp(indexToOutputIndex(parameterIndex));
   }
 
   @Override
@@ -419,7 +445,7 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
 
   @Override
   public Blob getBlob(int parameterIndex) throws SQLException {
-    return getOutputResult().getBlob(parameterIndex);
+    return getOutputResult().getBlob(indexToOutputIndex(parameterIndex));
   }
 
   @Override
@@ -459,12 +485,12 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
 
   @Override
   public RowId getRowId(int parameterIndex) throws SQLException {
-    throw ExceptionMapper.getFeatureNotSupportedException("RowIDs not supported");
+    throw exceptionFactory.notSupported("RowIDs not supported");
   }
 
   @Override
   public RowId getRowId(String parameterName) throws SQLException {
-    throw ExceptionMapper.getFeatureNotSupportedException("RowIDs not supported");
+    throw exceptionFactory.notSupported("RowIDs not supported");
   }
 
   @Override
@@ -479,12 +505,12 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
 
   @Override
   public SQLXML getSQLXML(int parameterIndex) throws SQLException {
-    throw ExceptionMapper.getFeatureNotSupportedException("SQLXML not supported");
+    throw exceptionFactory.notSupported("SQLXML not supported");
   }
 
   @Override
   public SQLXML getSQLXML(String parameterName) throws SQLException {
-    throw ExceptionMapper.getFeatureNotSupportedException("SQLXML not supported");
+    throw exceptionFactory.notSupported("SQLXML not supported");
   }
 
   @Override
@@ -645,12 +671,12 @@ public abstract class CallableProcedureStatement extends ServerSidePreparedState
 
   @Override
   public void setSQLXML(String parameterName, SQLXML xmlObject) throws SQLException {
-    throw ExceptionMapper.getFeatureNotSupportedException("SQLXML not supported");
+    throw exceptionFactory.notSupported("SQLXML not supported");
   }
 
   @Override
   public void setRowId(String parameterName, RowId rowid) throws SQLException {
-    throw ExceptionMapper.getFeatureNotSupportedException("RowIDs not supported");
+    throw exceptionFactory.notSupported("RowIDs not supported");
   }
 
   @Override
