@@ -510,6 +510,26 @@ public class MariaDbConnection implements Connection {
     }
   }
 
+  public CallableParameterMetaData getInternalParameterMetaData(
+      String procedureName, String databaseName, boolean isFunction) throws SQLException {
+    PreparedStatement prep =
+        new ClientSidePreparedStatement(
+            this,
+            "SELECT * from information_schema.PARAMETERS "
+                + "WHERE SPECIFIC_NAME = ? "
+                + "AND SPECIFIC_SCHEMA = "
+                + (databaseName != null ? "?" : "DATABASE()")
+                + " ORDER BY ORDINAL_POSITION",
+            ResultSet.TYPE_FORWARD_ONLY,
+            ResultSet.CONCUR_READ_ONLY,
+            Statement.NO_GENERATED_KEYS,
+            exceptionFactory);
+    prep.setString(1, procedureName);
+    if (databaseName != null) prep.setString(2, databaseName);
+    ResultSet rs = prep.executeQuery();
+    return new CallableParameterMetaData(rs, isFunction);
+  }
+
   /**
    * Creates a <code>CallableStatement</code> object for calling database stored procedures. The
    * <code>CallableStatement</code> object provides methods for setting up its IN and OUT
@@ -704,7 +724,7 @@ public class MariaDbConnection implements Connection {
 
     try (Statement stmt = createStatement()) {
       stateFlag |= ConnectionState.STATE_AUTOCOMMIT;
-      stmt.executeUpdate("set autocommit=" + ((autoCommit) ? "1" : "0"));
+      stmt.executeUpdate(autoCommit ? "set autocommit=1" : "set autocommit=0");
     }
   }
 
@@ -1207,7 +1227,11 @@ public class MariaDbConnection implements Connection {
     try {
       return protocol.isValid(timeout * 1000);
     } catch (SQLException e) {
-      // eat
+      if (pooledConnection != null) {
+        MariaDbPooledConnection poolConnection = this.pooledConnection;
+        poolConnection.fireConnectionErrorOccurred(e);
+        poolConnection.close();
+      }
       return false;
     }
   }
