@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,14 +52,16 @@
 
 package org.mariadb.jdbc.internal.com.send.parameters;
 
-import org.mariadb.jdbc.internal.*;
-import org.mariadb.jdbc.internal.io.output.*;
-import org.mariadb.jdbc.util.*;
-
-import java.io.*;
-import java.time.*;
-import java.time.format.*;
-import java.util.*;
+import java.io.IOException;
+import java.time.ZoneId;
+import java.time.ZoneOffset;
+import java.time.ZonedDateTime;
+import java.time.format.DateTimeFormatter;
+import java.util.Locale;
+import java.util.TimeZone;
+import org.mariadb.jdbc.internal.ColumnType;
+import org.mariadb.jdbc.internal.io.output.PacketOutputStream;
+import org.mariadb.jdbc.util.Options;
 
 /**
  * server doesn't support temporal with timezone (MDEV-10018) for the moment. So driver parse String
@@ -74,13 +76,13 @@ public class ZonedDateTimeParameter implements Cloneable, ParameterHolder {
    * Constructor.
    *
    * @param tz zone date time
-   * @param serverZoneId server session zoneId
+   * @param timezone server session timezone
    * @param fractionalSeconds must fractional Seconds be send to database.
    * @param options session options
    */
   public ZonedDateTimeParameter(
-      ZonedDateTime tz, ZoneId serverZoneId, boolean fractionalSeconds, Options options) {
-    ZoneId zoneId = options.useLegacyDatetimeCode ? ZoneOffset.systemDefault() : serverZoneId;
+      ZonedDateTime tz, TimeZone timezone, boolean fractionalSeconds, Options options) {
+    ZoneId zoneId = timezone == null ? ZoneOffset.systemDefault() : timezone.toZoneId();
     this.tz = tz.withZoneSameInstant(zoneId);
     this.fractionalSeconds = fractionalSeconds;
   }
@@ -100,7 +102,7 @@ public class ZonedDateTimeParameter implements Cloneable, ParameterHolder {
     pos.write(QUOTE);
   }
 
-  public long getApproximateTextProtocolLength() {
+  public int getApproximateTextProtocolLength() {
     return 27;
   }
 
@@ -136,7 +138,7 @@ public class ZonedDateTimeParameter implements Cloneable, ParameterHolder {
     return false;
   }
 
-  public boolean isLongData() {
+  public boolean canBeLongData() {
     return false;
   }
 }
