@@ -145,7 +145,7 @@ public class Pool implements AutoCloseable, PoolMBean {
               try {
                 addConnection();
               } catch (SQLException sqle) {
-                // eat
+                logger.error("error adding connection to pool", sqle);
               }
             }
           });
@@ -287,8 +287,6 @@ public class Pool implements AutoCloseable, PoolMBean {
           // eat
         }
 
-        totalConnection.decrementAndGet();
-
         // validation failed
         silentAbortConnection(item);
         addConnectionRequest();
@@ -334,7 +332,13 @@ public class Pool implements AutoCloseable, PoolMBean {
             if (poolState.get() == POOL_STATE_OK) {
               try {
                 if (!idleConnections.contains(item)) {
+                  // remove pool connection to avoid throwing connectionErrorOccurred
+                  item.getConnection().pooledConnection = null;
+
                   item.getConnection().reset();
+
+                  // set pool connection back
+                  item.getConnection().pooledConnection = item;
                   idleConnections.addFirst(item);
                 }
               } catch (SQLException sqle) {
@@ -342,7 +346,13 @@ public class Pool implements AutoCloseable, PoolMBean {
                 // sql exception during reset, removing connection from pool
                 totalConnection.decrementAndGet();
                 silentCloseConnection(item);
-                logger.debug("connection removed from pool {} due to error during reset", poolTag);
+                logger.debug(
+                    "connection {} removed from pool {} due to error during reset (total:{}, active:{}, pending:{})",
+                    item.getConnection().getServerThreadId(),
+                    poolTag,
+                    totalConnection.get(),
+                    getActiveConnections(),
+                    pendingRequestNumber.get());
               }
             } else {
               // pool is closed, should then not be render to pool, but closed.
@@ -357,12 +367,16 @@ public class Pool implements AutoCloseable, PoolMBean {
 
           @Override
           public void connectionErrorOccurred(ConnectionEvent event) {
-
             MariaDbPooledConnection item = ((MariaDbPooledConnection) event.getSource());
-            if (idleConnections.remove(item)) {
-              totalConnection.decrementAndGet();
-            }
+            totalConnection.decrementAndGet();
+            // if occurs when idle, remove from list
+            idleConnections.remove(item);
             silentCloseConnection(item);
+
+            // ensure that other connection will be validated before being use
+            // since one connection failed, better to assume the other might as well
+            idleConnections.stream().forEach(c -> c.lastUsedToNow());
+
             addConnectionRequest();
             logger.debug(
                 "connection {} removed from pool {} due to having throw a Connection exception (total:{}, active:{}, pending:{})",
