@@ -82,30 +82,6 @@ import org.mariadb.jdbc.util.Options;
 public class BaseTest {
   protected static String mDefUrl;
 
-  static {
-    try (InputStream inputStream =
-        BaseTest.class.getClassLoader().getResourceAsStream("conf.properties")) {
-      Properties prop = new Properties();
-      prop.load(inputStream);
-      mDefUrl =
-          String.format(
-              "jdbc:mariadb://%s:%s/%s?user=%s&password=%s&%s",
-              prop.getProperty("DB_HOST"),
-              prop.getProperty("DB_PORT"),
-              prop.getProperty("DB_DATABASE"),
-              prop.getProperty("DB_USER"),
-              prop.getProperty("DB_PASSWORD"),
-              prop.getProperty("DB_OTHER"));
-
-    } catch (IOException io) {
-      io.printStackTrace();
-    }
-  }
-
-  private static final Set<String> tempTableList = new HashSet<>();
-  private static final Set<String> tempViewList = new HashSet<>();
-  private static final Set<String> tempProcedureList = new HashSet<>();
-  private static final Set<String> tempFunctionList = new HashSet<>();
   private static final NumberFormat numberFormat = DecimalFormat.getInstance(Locale.ROOT);
   protected static String connU;
   protected static String connUri;
@@ -121,15 +97,49 @@ public class BaseTest {
   protected static Connection sharedConnection;
   protected static boolean runLongTest = false;
   protected static boolean doPrecisionTest = true;
-  private static TcpProxy proxy = null;
+  protected static TcpProxy proxy = null;
   private static UrlParser urlParser;
 
+  static {
+    try (InputStream inputStream =
+        BaseTest.class.getClassLoader().getResourceAsStream("conf.properties")) {
+      Properties prop = new Properties();
+      prop.load(inputStream);
+      String defaultOther;
+      String val = System.getenv("TEST_REQUIRE_TLS");
+      defaultOther = get("DB_OTHER", prop);
+      if ("1".equals(val)) {
+        String cert = System.getenv("TEST_DB_SERVER_CERT");
+        defaultOther += "&useSsl&serverSslCert=" + cert;
+      }
+      hostname = get("DB_HOST", prop);
+      username = get("DB_USER", prop);
+      port = Integer.parseInt(get("DB_PORT", prop));
+      password = get("DB_PASSWORD", prop);
+      mDefUrl =
+          String.format(
+              "jdbc:mariadb://%s:%s/%s?user=%s&password=%s&%s",
+              hostname, port, get("DB_DATABASE", prop), username, password, defaultOther);
+
+    } catch (IOException io) {
+      io.printStackTrace();
+    }
+  }
+
+  private static String get(String name, Properties prop) {
+    String val = System.getenv("TEST_" + name);
+    if (val == null) val = System.getProperty("TEST_" + name);
+    if (val == null) val = prop.getProperty(name);
+    return val;
+  }
+
   @Rule
   public TestRule watcher =
       new TestWatcher() {
         private long ttime;
 
         protected void starting(Description description) {
+
           if (testSingleHost) {
             System.out.println(
                 "start test : " + description.getClassName() + "." + description.getMethodName());
@@ -150,7 +160,7 @@ public class BaseTest {
             } catch (SQLNonTransientConnectionException connFail) {
               connFail.printStackTrace();
               try {
-                beforeClassBaseTest();
+                aBefore();
               } catch (SQLException e) {
                 System.out.println("ERROR reconnecting");
                 e.printStackTrace();
@@ -205,7 +215,7 @@ public class BaseTest {
    * @throws SQLException exception
    */
   @BeforeClass()
-  public static void beforeClassBaseTest() throws SQLException {
+  public static void aBefore() throws SQLException {
     String url = System.getProperty("dbUrl", mDefUrl);
     runLongTest = Boolean.parseBoolean(System.getProperty("runLongTest", "false"));
     testSingleHost = Boolean.parseBoolean(System.getProperty("testSingleHost", "true"));
@@ -287,49 +297,8 @@ public class BaseTest {
    * @throws SQLException exception
    */
   @AfterClass
-  public static void afterClassBaseTest() throws SQLException {
+  public static void after() throws Throwable {
     if (testSingleHost && sharedConnection != null && !sharedConnection.isClosed()) {
-      if (!tempViewList.isEmpty()) {
-        Statement stmt = sharedConnection.createStatement();
-        for (String viewName : tempViewList) {
-          try {
-            stmt.execute("DROP VIEW IF EXISTS " + viewName);
-          } catch (SQLException e) {
-            // eat exception
-          }
-        }
-      }
-      if (!tempTableList.isEmpty()) {
-        Statement stmt = sharedConnection.createStatement();
-        for (String tableName : tempTableList) {
-          try {
-            stmt.execute("DROP TABLE IF EXISTS " + tableName);
-          } catch (SQLException e) {
-            // eat exception
-          }
-        }
-      }
-      if (!tempProcedureList.isEmpty()) {
-        Statement stmt = sharedConnection.createStatement();
-        for (String procedureName : tempProcedureList) {
-          try {
-            stmt.execute("DROP procedure IF EXISTS " + procedureName);
-          } catch (SQLException e) {
-            // eat exception
-          }
-        }
-      }
-      if (!tempFunctionList.isEmpty()) {
-        Statement stmt = sharedConnection.createStatement();
-        for (String functionName : tempFunctionList) {
-          try {
-            stmt.execute("DROP FUNCTION IF EXISTS " + functionName);
-          } catch (SQLException e) {
-            // eat exception
-          }
-        }
-      }
-
       try {
         sharedConnection.close();
       } catch (SQLException e) {
@@ -337,8 +306,25 @@ public class BaseTest {
       }
     }
     if (!Platform.isWindows()) {
+
       Iterator<Thread> it = Thread.getAllStackTraces().keySet().iterator();
+      boolean ok = true;
       Thread thread;
+      while (it.hasNext()) {
+        thread = it.next();
+        if (thread.getName().contains("MariaDb-bulk-")) {
+          if (thread.getState() != State.WAITING) {
+            // print stack trace to console.
+            for (StackTraceElement ste : thread.getStackTrace()) {
+              System.out.println(ste);
+            }
+          }
+          if (thread.getState() != State.WAITING) ok = false;
+        }
+      }
+      if (ok) return;
+      Thread.sleep(1000);
+      it = Thread.getAllStackTraces().keySet().iterator();
       while (it.hasNext()) {
         thread = it.next();
         if (thread.getName().contains("MariaDb-bulk-")) {
@@ -359,91 +345,6 @@ public class BaseTest {
     System.out.println(message);
   }
 
-  /**
-   * Create a table that will be detroyed a the end of tests.
-   *
-   * @param tableName table name
-   * @param tableColumns table columns
-   * @throws SQLException exception
-   */
-  public static void createTable(String tableName, String tableColumns) throws SQLException {
-    createTable(tableName, tableColumns, null);
-  }
-
-  /**
-   * Create a table that will be detroyed a the end of tests.
-   *
-   * @param tableName table name
-   * @param tableColumns table columns
-   * @param engine engine type
-   * @throws SQLException exception
-   */
-  public static void createTable(String tableName, String tableColumns, String engine)
-      throws SQLException {
-    if (testSingleHost) {
-      Statement stmt = sharedConnection.createStatement();
-      stmt.execute("drop table if exists " + tableName);
-      stmt.execute(
-          "create table "
-              + tableName
-              + " ("
-              + tableColumns
-              + ") "
-              + ((engine != null) ? engine : ""));
-      if (!tempFunctionList.contains(tableName)) {
-        tempTableList.add(tableName);
-      }
-    }
-  }
-
-  /**
-   * Create a view that will be detroyed a the end of tests.
-   *
-   * @param viewName table name
-   * @param tableColumns table columns
-   * @throws SQLException exception
-   */
-  public static void createView(String viewName, String tableColumns) throws SQLException {
-    if (testSingleHost) {
-      Statement stmt = sharedConnection.createStatement();
-      stmt.execute("drop view if exists " + viewName);
-      stmt.execute("create view " + viewName + " AS (" + tableColumns + ") ");
-      tempViewList.add(viewName);
-    }
-  }
-
-  /**
-   * Create procedure that will be delete on end of test.
-   *
-   * @param name procedure name
-   * @param body procecure body
-   * @throws SQLException exception
-   */
-  public static void createProcedure(String name, String body) throws SQLException {
-    if (testSingleHost) {
-      Statement stmt = sharedConnection.createStatement();
-      stmt.execute("drop procedure IF EXISTS " + name);
-      stmt.execute("create  procedure " + name + body);
-      tempProcedureList.add(name);
-    }
-  }
-
-  /**
-   * Create function that will be delete on end of test.
-   *
-   * @param name function name
-   * @param body function body
-   * @throws SQLException exception
-   */
-  public static void createFunction(String name, String body) throws SQLException {
-    if (testSingleHost) {
-      Statement stmt = sharedConnection.createStatement();
-      stmt.execute("drop function IF EXISTS " + name);
-      stmt.execute("create function " + name + body);
-      tempFunctionList.add(name);
-    }
-  }
-
   /**
    * Check if current DB server is MariaDB.
    *
@@ -670,7 +571,7 @@ public class BaseTest {
     return openConnection(connUri + parameters, null);
   }
 
-  protected Connection setConnection(String additionalParameters, String database)
+  protected Connection setConnection(String additionalParameters, String database, int port)
       throws SQLException {
     StringBuilder sb = new StringBuilder();
     sb.append("jdbc:mariadb://");
@@ -920,7 +821,7 @@ public class BaseTest {
    * @param connection connection to check
    * @return true if SSL is enabled
    */
-  public boolean haveSsl(Connection connection) {
+  public static boolean haveSsl(Connection connection) {
     try {
       ResultSet rs = connection.createStatement().executeQuery("select @@have_ssl");
       assertTrue(rs.next());
@@ -937,7 +838,7 @@ public class BaseTest {
    * @param minor database minor version
    * @throws SQLException exception
    */
-  public boolean minVersion(int major, int minor) throws SQLException {
+  public static boolean minVersion(int major, int minor) throws SQLException {
     DatabaseMetaData md = sharedConnection.getMetaData();
     int dbMajor = md.getDatabaseMajorVersion();
     int dbMinor = md.getDatabaseMinorVersion();
@@ -951,7 +852,7 @@ public class BaseTest {
    * @param minor database minor version
    * @throws SQLException exception
    */
-  public boolean strictBeforeVersion(int major, int minor) throws SQLException {
+  public static boolean strictBeforeVersion(int major, int minor) throws SQLException {
     DatabaseMetaData md = sharedConnection.getMetaData();
     int dbMajor = md.getDatabaseMajorVersion();
     int dbMinor = md.getDatabaseMinorVersion();
@@ -988,43 +889,6 @@ public class BaseTest {
     Assume.assumeTrue(minVersion(major, minor));
   }
 
-  /**
-   * Cancel if Maxscale version isn't required minimum.
-   *
-   * @param major minimum maxscale major version
-   * @param minor minimum maxscale minor version
-   */
-  public void ifMaxscaleRequireMinimumVersion(int major, int minor) {
-    String maxscaleVersion = System.getenv("MAXSCALE_VERSION");
-    if (maxscaleVersion == null) {
-      return;
-    }
-
-    String[] versionArray = maxscaleVersion.split("[^0-9]");
-
-    int majorVersion = 0;
-    int minorVersion = 0;
-
-    // standard version
-    if (versionArray.length > 2) {
-
-      majorVersion = Integer.parseInt(versionArray[0]);
-      minorVersion = Integer.parseInt(versionArray[1]);
-
-    } else {
-
-      if (versionArray.length > 0) {
-        majorVersion = Integer.parseInt(versionArray[0]);
-      }
-
-      if (versionArray.length > 1) {
-        minorVersion = Integer.parseInt(versionArray[1]);
-      }
-    }
-
-    Assume.assumeTrue(majorVersion > major || (majorVersion == major && minorVersion >= minor));
-  }
-
   /**
    * Change session time zone.
    *
