@@ -1,10 +1,13 @@
 package org.mariadb.jdbc;
 
-import org.junit.*;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
-import java.sql.*;
-
-import static org.junit.Assert.*;
+import java.sql.Connection;
+import java.sql.DriverManager;
+import java.sql.SQLNonTransientConnectionException;
+import java.sql.Statement;
+import org.junit.Test;
 
 public class BasicFailover extends BaseTest {
 
@@ -21,6 +24,8 @@ public class BasicFailover extends BaseTest {
                 + "?user="
                 + username
                 + ((password != null) ? "&password=" + password : "")
+                + ((options.useSsl != null) ? "&useSsl=" + options.useSsl : "")
+                + ((options.serverSslCert != null) ? "&serverSslCert=" + options.serverSslCert : "")
                 + "&socketTimeout=1000")) {
       try (Statement stmt = connection.createStatement()) {
         stmt.execute("SELECT SLEEP(10)");
