@@ -61,7 +61,7 @@ public class CallStatementTest extends BaseTest {
 
   @BeforeClass()
   public static void initClass() throws SQLException {
-    afterClass();
+    drop();
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("CREATE PROCEDURE useParameterName(a int) begin select a; end");
       stmt.execute("CREATE PROCEDURE useWrongParameterName(a int) begin select a; end");
@@ -93,7 +93,7 @@ public class CallStatementTest extends BaseTest {
   }
 
   @AfterClass
-  public static void afterClass() throws SQLException {
+  public static void drop() throws SQLException {
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("DROP PROCEDURE IF EXISTS useParameterName");
       stmt.execute("DROP PROCEDURE IF EXISTS useWrongParameterName");
@@ -168,6 +168,32 @@ public class CallStatementTest extends BaseTest {
     }
   }
 
+  @Test
+  public void functionParameterByNameError() throws SQLException {
+    try (CallableStatement call =
+        sharedConnection.prepareCall("{? = call stmtSimpleFunction(?,?,?)}")) {
+      call.setInt("a", 8);
+      call.setInt(3, 2);
+      call.setInt(4, 2);
+      call.execute();
+
+      try {
+        call.getString("b");
+        fail("must have thrown exception");
+      } catch (SQLDataException ee) {
+        assertTrue(ee.getMessage().contains("No such column"));
+      }
+
+      try {
+        call.getString("d");
+        fail("must have thrown exception");
+      } catch (SQLSyntaxErrorException ee) {
+        assertTrue(ee.getMessage().contains("there is no parameter with the name d"));
+      }
+      assertEquals(8, call.getInt(1));
+    }
+  }
+
   @Test
   public void prepareStmtWithOutParameter() throws SQLException {
     Assume.assumeTrue(sharedUsePrepare());
@@ -225,6 +251,10 @@ public class CallStatementTest extends BaseTest {
 
   @Test
   public void stmtInoutParam() throws SQLException {
+    try (Connection connection = setConnection("&dumpQueriesOnException")) {
+      // to ensure not having too many connection error for maxscale
+      connection.isValid(1);
+    }
     try (Connection connection = setConnection("&dumpQueriesOnException")) {
       Statement stmt = connection.createStatement();
       stmt.execute("{call inOutParam(1)}");
