@@ -3,7 +3,7 @@
  * MariaDB Client for Java
  *
  * Copyright (c) 2012-2014 Monty Program Ab.
- * Copyright (c) 2015-2019 MariaDB Ab.
+ * Copyright (c) 2015-2020 MariaDB Corporation Ab.
  *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
@@ -52,11 +52,11 @@
 
 package org.mariadb.jdbc;
 
-import org.junit.*;
+import static org.junit.Assert.*;
 
 import java.sql.*;
-
-import static org.junit.Assert.*;
+import org.junit.Assume;
+import org.junit.Test;
 
 public class ClientPreparedStatementTest extends BaseTest {
 
@@ -261,12 +261,7 @@ public class ClientPreparedStatementTest extends BaseTest {
   @Test
   public void metaDataForWrongQuery() throws SQLException {
     PreparedStatement preparedStatement = sharedConnection.prepareStatement("WRONG QUERY");
-    try {
-      preparedStatement.getMetaData();
-      fail();
-    } catch (SQLSyntaxErrorException e) {
-      assertTrue(e.getMessage().contains("You have an error in your SQL syntax"));
-    }
+    assertNull(preparedStatement.getMetaData());
   }
 
   @Test
