@@ -67,7 +67,7 @@ public class ConnectionTest extends BaseTest {
 
   @BeforeClass()
   public static void initClass() throws SQLException {
-    afterClass();
+    drop();
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("CREATE TABLE dummy(a BLOB)");
       stmt.execute("CREATE DATABASE gogogo");
@@ -76,7 +76,7 @@ public class ConnectionTest extends BaseTest {
   }
 
   @AfterClass
-  public static void afterClass() throws SQLException {
+  public static void drop() throws SQLException {
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("DROP TABLE IF EXISTS dummy");
       stmt.execute("DROP DATABASE IF EXISTS gogogo");
@@ -321,9 +321,9 @@ public class ConnectionTest extends BaseTest {
   public void isValidConnectionThatTimesOutByServer() throws SQLException, InterruptedException {
     Assume.assumeTrue(
         !sharedIsAurora()
-            && System.getenv("SKYSQL") == null
-            && System.getenv("SKYSQL_HA") == null
-            && System.getenv("MAXSCALE_TEST_DISABLE") == null);
+            && !"skysql".equals(System.getenv("srv"))
+            && !"skysql-ha".equals(System.getenv("srv"))
+            && !"maxscale".equals(System.getenv("srv")));
     try (Connection connection = setConnection()) {
       try (Statement statement = connection.createStatement()) {
         statement.execute("set session wait_timeout=1");
@@ -594,9 +594,9 @@ public class ConnectionTest extends BaseTest {
   @Test
   public void verificationEd25519AuthPlugin() throws Throwable {
     Assume.assumeTrue(
-        System.getenv("MAXSCALE_TEST_DISABLE") == null
-            && System.getenv("SKYSQL") == null
-            && System.getenv("SKYSQL_HA") == null);
+        !"maxscale".equals(System.getenv("srv"))
+            && !"skysql".equals(System.getenv("srv"))
+            && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeTrue(isMariadbServer() && minVersion(10, 2));
     Statement stmt = sharedConnection.createStatement();
 
@@ -690,7 +690,8 @@ public class ConnectionTest extends BaseTest {
 
   @Test
   public void replicaDownConnection() throws SQLException {
-    Assume.assumeTrue(System.getenv("SKYSQL") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
     String url =
         "jdbc:mariadb:replication://"
             + hostname
@@ -722,9 +723,9 @@ public class ConnectionTest extends BaseTest {
   @Test
   public void multiAuthPlugin() throws Throwable {
     Assume.assumeTrue(
-        System.getenv("MAXSCALE_TEST_DISABLE") == null
-            && System.getenv("SKYSQL") == null
-            && System.getenv("SKYSQL_HA") == null);
+        !"maxscale".equals(System.getenv("srv"))
+            && !"skysql".equals(System.getenv("srv"))
+            && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeTrue(isMariadbServer() && minVersion(10, 4, 2));
     Statement stmt = sharedConnection.createStatement();
     try {
@@ -782,7 +783,8 @@ public class ConnectionTest extends BaseTest {
 
   @Test
   public void connectionUnexpectedClose() throws SQLException {
-    Assume.assumeTrue(System.getenv("SKYSQL") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
     try (Connection connection =
         DriverManager.getConnection(
             "jdbc:mariadb:failover//"
@@ -810,6 +812,41 @@ public class ConnectionTest extends BaseTest {
     }
   }
 
+  @Test
+  public void ensureSocketTimeoutState() throws Throwable {
+    Assume.assumeTrue(
+        !"maxscale".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
+
+    Statement stmt = sharedConnection.createStatement();
+    stmt.execute("DROP TABLE IF EXISTS ensureSocketTimeoutState");
+    stmt.execute("CREATE TABLE ensureSocketTimeoutState(id int auto_increment primary key)");
+    stmt.execute("INSERT INTO ensureSocketTimeoutState VALUES (1), (3), (5), (7), (9)");
+
+    new Thread(
+            () -> {
+              try (Connection conn = setConnection("&socketTimeout=1000")) {
+                Statement stmt2 = conn.createStatement();
+                stmt2.execute("BEGIN");
+                stmt2.execute("DELETE FROM ensureSocketTimeoutState WHERE id IN (1, 3, 5, 7, 9)");
+                stmt2.execute("SELECT SLEEP(30)");
+              } catch (SQLException e) {
+                // eat
+              }
+            })
+        .start();
+    Thread.sleep(100);
+
+    long insertStart = System.currentTimeMillis();
+
+    try (Connection conn = setConnection()) {
+      Statement stmt2 = conn.createStatement();
+      stmt2.execute("BEGIN");
+      stmt2.execute("INSERT INTO ensureSocketTimeoutState VALUES (2)");
+      stmt2.execute("COMMIT");
+    }
+    assertTrue(System.currentTimeMillis() - insertStart < 5000);
+  }
+
   @Test
   public void prepareStatementCols() throws SQLException {
     try (PreparedStatement preparedStatement =
@@ -837,7 +874,8 @@ public class ConnectionTest extends BaseTest {
 
   @Test
   public void setReadonlyError() throws SQLException {
-    Assume.assumeTrue(System.getenv("SKYSQL") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
     try (Connection connection =
         DriverManager.getConnection(
             "jdbc:mariadb:replication://"
@@ -873,6 +911,9 @@ public class ConnectionTest extends BaseTest {
   @Test
   public void testWarnings() throws SQLException {
     Assume.assumeTrue(isMariadbServer());
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
+
     Statement stmt = sharedConnection.createStatement();
     stmt.executeQuery("select now() = 1");
     SQLWarning warning = sharedConnection.getWarnings();
@@ -934,9 +975,9 @@ public class ConnectionTest extends BaseTest {
   @Test
   public void setClientNotConnectError() throws SQLException {
     Assume.assumeTrue(
-        System.getenv("MAXSCALE_TEST_DISABLE") == null
-            && System.getenv("SKYSQL") == null
-            && System.getenv("SKYSQL_HA") == null);
+        !"maxscale".equals(System.getenv("srv"))
+            && !"skysql".equals(System.getenv("srv"))
+            && !"skysql-ha".equals(System.getenv("srv")));
     // only mariadb return a specific error when connection has explicitly been killed
     Assume.assumeTrue(isMariadbServer());
 
