@@ -61,7 +61,7 @@ public class DatabaseMetadataTest extends BaseTest {
 
   @BeforeClass()
   public static void initClass() throws SQLException {
-    afterClass();
+    drop();
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute(
           "CREATE TABLE dbpk_test(val varchar(20), id1 int not null, id2 int not null,primary key(id1, id2)) engine=innodb");
@@ -184,7 +184,7 @@ public class DatabaseMetadataTest extends BaseTest {
   }
 
   @AfterClass
-  public static void afterClass() throws SQLException {
+  public static void drop() throws SQLException {
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("DROP TABLE IF EXISTS dbpk_test");
       stmt.execute("DROP TABLE IF EXISTS datetime_test");
@@ -240,6 +240,55 @@ public class DatabaseMetadataTest extends BaseTest {
     assertEquals(2, counter);
   }
 
+  @Test
+  public void foreignKeyTest() throws SQLException {
+
+    try (Connection con = setConnection("")) {
+      foreignKeyTest(con, true);
+    }
+    try (Connection con = setConnection("&nullCatalogMeansCurrent=false")) {
+      foreignKeyTest(con, false);
+    }
+  }
+
+  private void foreignKeyTest(Connection con, boolean nullAsCurrent) throws SQLException {
+    String db = con.getCatalog();
+    Statement stmt = con.createStatement();
+    stmt.execute("DROP DATABASE IF EXISTS dbTmp");
+    stmt.execute("DROP TABLE IF EXISTS tableWithForeignKey");
+    stmt.execute("DROP TABLE IF EXISTS tableWithPk");
+    stmt.execute("CREATE TABLE tableWithPk(id BIGINT PRIMARY KEY) ENGINE=InnoDB");
+
+    stmt.execute(
+        "CREATE TABLE IF NOT EXISTS tableWithForeignKey\n"
+            + "          (\n"
+            + "                  id BIGINT NOT NULL AUTO_INCREMENT,\n"
+            + "                  fk_id BIGINT,\n"
+            + "                  PRIMARY KEY (id),\n"
+            + "  CONSTRAINT fk_key FOREIGN KEY (fk_id) REFERENCES tableWithPk (id)\n"
+            + "          ) ENGINE=InnoDB");
+    DatabaseMetaData dbmd = con.getMetaData();
+    ResultSet rs = dbmd.getImportedKeys(null, null, "tableWithForeignKey");
+    assertTrue(rs.next());
+    rs.close();
+
+    rs = dbmd.getImportedKeys("", null, "tableWithForeignKey");
+    assertTrue(rs.next());
+
+    stmt.execute("CREATE DATABASE dbTmp");
+    con.setCatalog("dbTmp");
+    try {
+      rs = dbmd.getImportedKeys("", null, "tableWithForeignKey");
+      assertFalse(rs.next());
+
+      rs = dbmd.getImportedKeys(null, null, "tableWithForeignKey");
+      assertEquals(!nullAsCurrent, rs.next());
+    } finally {
+      con.setCatalog(db);
+      stmt.execute("DROP DATABASE dbTmp");
+    }
+  }
+
   @Test
   public void primaryKeyTest2() throws SQLException {
     Statement stmt = sharedConnection.createStatement();
@@ -541,13 +590,36 @@ public class DatabaseMetadataTest extends BaseTest {
 
   @Test
   public void testGetTables() throws SQLException {
-    Statement stmt = sharedConnection.createStatement();
-    DatabaseMetaData dbmd = sharedConnection.getMetaData();
-    ResultSet rs = dbmd.getTables(null, null, "prim_key", null);
+    try (Connection con = setConnection("")) {
+      testGetTables(con, true);
+    }
+    try (Connection con = setConnection("&nullCatalogMeansCurrent=false")) {
+      testGetTables(con, false);
+    }
+  }
 
-    assertEquals(true, rs.next());
+  private void testGetTables(Connection conn, boolean nullCatalogMeansCurrent) throws SQLException {
+    Statement stmt = conn.createStatement();
+    DatabaseMetaData dbmd = conn.getMetaData();
+    ResultSet rs = dbmd.getTables(null, null, "prim_key", null);
+    assertTrue(rs.next());
     rs = dbmd.getTables("", null, "prim_key", null);
-    assertEquals(true, rs.next());
+    assertTrue(rs.next());
+
+    String db = conn.getCatalog();
+    stmt.execute("DROP DATABASE IF EXISTS dbTmp");
+    stmt.execute("CREATE DATABASE dbTmp");
+    conn.setCatalog("dbTmp");
+    try {
+      rs = dbmd.getTables("", null, "prim_key", null);
+      assertFalse(rs.next());
+      rs = dbmd.getTables(null, null, "prim_key", null);
+      assertEquals(!nullCatalogMeansCurrent, rs.next());
+
+    } finally {
+      conn.setCatalog(db);
+      stmt.execute("DROP DATABASE dbTmp");
+    }
   }
 
   @Test
