@@ -71,7 +71,7 @@ public class DriverTest extends BaseTest {
 
   @BeforeClass()
   public static void initClass() throws SQLException {
-    afterClass();
+    drop();
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("CREATE TABLE tt1(id int , name varchar(20))");
       stmt.execute("CREATE TABLE tt2(id int , name varchar(20))");
@@ -130,7 +130,7 @@ public class DriverTest extends BaseTest {
   }
 
   @AfterClass
-  public static void afterClass() throws SQLException {
+  public static void drop() throws SQLException {
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("DROP TABLE IF EXISTS tt1");
       stmt.execute("DROP TABLE IF EXISTS tt2");
@@ -275,7 +275,8 @@ public class DriverTest extends BaseTest {
 
   @Test
   public void parameterMetaDataNotPreparable() throws SQLException {
-    Assume.assumeTrue(System.getenv("SKYSQL") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeFalse(sharedUsePrepare());
     Statement stmt = sharedConnection.createStatement();
     Map<String, Integer> initValues = loadVariables(stmt);
@@ -319,7 +320,8 @@ public class DriverTest extends BaseTest {
 
   @Test
   public void parameterMetaDataPreparable() throws SQLException {
-    Assume.assumeTrue(System.getenv("SKYSQL") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeFalse(sharedUsePrepare());
     Statement stmt = sharedConnection.createStatement();
     Map<String, Integer> initValues = loadVariables(stmt);
@@ -956,16 +958,20 @@ public class DriverTest extends BaseTest {
     Statement stmt =
         sharedConnection.createStatement(ResultSet.TYPE_FORWARD_ONLY, ResultSet.CONCUR_READ_ONLY);
     stmt.execute("TRUNCATE streamingressetpos");
-    stmt.execute("INSERT INTO streamingressetpos VALUES (1), (2), (3), (4), (5), (6)");
-
-    stmt.setFetchSize(2);
-    ResultSet rs = stmt.executeQuery("SELECT * FROM streamingressetpos");
-    for (int i = 1; i <= 6; i++) {
-      assertTrue(rs.next());
-      assertEquals(i, rs.getRow());
+    stmt.execute("START TRANSACTION");
+    try {
+      stmt.execute("INSERT INTO streamingressetpos VALUES (1), (2), (3), (4), (5), (6)");
+      stmt.setFetchSize(2);
+      ResultSet rs = stmt.executeQuery("SELECT * FROM streamingressetpos");
+      for (int i = 1; i <= 6; i++) {
+        assertTrue(rs.next());
+        assertEquals(i, rs.getRow());
+      }
+      assertFalse(rs.next());
+      assertEquals(7, rs.getRow());
+    } finally {
+      sharedConnection.rollback();
     }
-    assertFalse(rs.next());
-    assertEquals(7, rs.getRow());
   }
 
   @Test(expected = SQLException.class)
@@ -1072,7 +1078,8 @@ public class DriverTest extends BaseTest {
 
   @Test
   public void testConnectWithDb() throws SQLException {
-    Assume.assumeTrue(System.getenv("SKYSQL") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
 
     requireMinimumVersion(5, 0);
     try {
@@ -1082,7 +1089,7 @@ public class DriverTest extends BaseTest {
     }
 
     try (Connection connection =
-        setConnection("&createDatabaseIfNotExist=true&profileSql=true", "test_testdrop")) {
+        setConnection("&createDatabaseIfNotExist=true&profileSql=true", "test_testdrop", port)) {
       DatabaseMetaData dbmd = connection.getMetaData();
       ResultSet rs = dbmd.getCatalogs();
       boolean foundDb = false;
@@ -1232,7 +1239,7 @@ public class DriverTest extends BaseTest {
       setConnection("&password=");
     } catch (SQLException ex) {
       // SQLException is ok because we might get for example an access denied exception
-      if (!(ex.getMessage().contains("Could not connect: Access denied"))) {
+      if (!(ex.getMessage().contains("Access denied"))) {
         throw ex;
       }
     }
@@ -1240,7 +1247,8 @@ public class DriverTest extends BaseTest {
 
   @Test
   public void conj1() throws Exception {
-    Assume.assumeTrue(System.getenv("SKYSQL") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
 
     requireMinimumVersion(5, 0);
 
@@ -1496,10 +1504,15 @@ public class DriverTest extends BaseTest {
     }
 
     String path = rs.getString(2);
+    st.execute("DROP user IF EXISTS testSocket@'localhost'");
     st.execute("CREATE USER testSocket@'localhost' IDENTIFIED BY 'MySup5%rPassw@ord'");
     st.execute("GRANT SELECT on *.* to testSocket@'localhost' IDENTIFIED BY 'MySup5%rPassw@ord'");
     st.execute("FLUSH PRIVILEGES");
-    String connString = connU + "?user=testSocket&password=MySup5%rPassw@ord&localSocket=" + path;
+    String connString =
+        "jdbc:mariadb:///"
+            + database
+            + "?user=testSocket&password=MySup5%rPassw@ord&localSocket="
+            + path;
 
     try (Connection connection = openConnection(connString, null)) {
       rs = connection.createStatement().executeQuery("select 1");
@@ -1603,7 +1616,7 @@ public class DriverTest extends BaseTest {
   @Test
   public void createDbWithSpacesTest() throws SQLException {
     try (Connection connection =
-        setConnection("&createDatabaseIfNotExist=true&profileSql=true", "test with spaces")) {
+        setConnection("&createDatabaseIfNotExist=true&profileSql=true", "test with spaces", port)) {
       DatabaseMetaData dbmd = connection.getMetaData();
       ResultSet rs = dbmd.getCatalogs();
       boolean foundDb = false;
@@ -1712,9 +1725,10 @@ public class DriverTest extends BaseTest {
 
   @Test
   public void databaseType() throws SQLException {
-    Assume.assumeTrue(System.getenv("SKYSQL") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeTrue(System.getenv("TRAVIS") != null);
-    boolean isMysql = System.getenv("AURORA") != null || System.getenv("DB").contains("mysql");
+    boolean isMysql = System.getenv("AURORA") != null || System.getenv("srv").contains("mysql");
     assertEquals(
         isMysql ? "MySQL" : "MariaDB", sharedConnection.getMetaData().getDatabaseProductName());
     if (!isMysql) {
