@@ -75,6 +75,33 @@ public class JdbcParserTest {
     assertEquals(jdbc.getHaMode(), jdbc2.getHaMode());
   }
 
+  @Test
+  public void testPropertiesObjectParsing() throws SQLException {
+    String url =
+        "jdbc:mariadb://master:3306,replica1:3307,replica2:3308/database?autoReconnect=true";
+
+    UrlParser urlParser = UrlParser.parse(url, null);
+    assertEquals("database", urlParser.getDatabase());
+    assertNull(urlParser.getUsername());
+    assertNull(urlParser.getPassword());
+    assertNull(urlParser.getOptions().useSsl);
+    assertNull(urlParser.getOptions().serverSslCert);
+
+    Properties prop = new Properties();
+    prop.setProperty("user", "greg");
+    prop.setProperty("password", "pass");
+    prop.put("useSSL", true);
+    prop.put("serverSslCert", "/path/to/cert.pem");
+
+    urlParser = UrlParser.parse(url, prop);
+
+    assertEquals("database", urlParser.getDatabase());
+    assertEquals("greg", urlParser.getUsername());
+    assertEquals("pass", urlParser.getPassword());
+    assertTrue(urlParser.getOptions().useSsl);
+    assertEquals("/path/to/cert.pem", urlParser.getOptions().serverSslCert);
+  }
+
   @Test
   public void testAuroraUseBatchMultiSend() throws Throwable {
     assertTrue(
@@ -619,7 +646,6 @@ public class JdbcParserTest {
             + "+LBCR0B194YbRn6726vWwUUE05yskVN6gllGSCgZ/G8y98DhjQ==\n"
             + "-----END CERTIFICATE-----&useSSL=true&password=testj&password=pwd2";
     UrlParser jdbc = UrlParser.parse(url);
-    assertEquals("diego", jdbc.getOptions().user);
     assertEquals(true, jdbc.getOptions().profileSql);
     assertEquals(
         "-----BEGIN CERTIFICATE-----\n"
@@ -643,7 +669,7 @@ public class JdbcParserTest {
             + "-----END CERTIFICATE-----",
         jdbc.getOptions().serverSslCert);
     assertEquals(true, jdbc.getOptions().useSsl);
-    assertEquals("testj", jdbc.getOptions().password);
+    assertEquals("pwd2", jdbc.getOptions().password);
   }
 
   /**
