@@ -1,12 +1,13 @@
 package org.mariadb.jdbc;
 
-import org.junit.*;
-
-import java.io.*;
-import java.sql.*;
-
 import static org.junit.Assert.*;
 
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.sql.SQLException;
+import org.junit.Test;
+
 public class MariaDbBlobTest {
 
   private final byte[] bytes = new byte[] {0, 1, 2, 3, 4, 5};
