@@ -85,7 +85,7 @@ public class StatementTest extends BaseTest {
 
   @BeforeClass()
   public static void initClass() throws SQLException {
-    afterClass();
+    drop();
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute(
           "CREATE TABLE vendor_code_test(id int not null primary key auto_increment, test boolean)");
@@ -113,7 +113,7 @@ public class StatementTest extends BaseTest {
   }
 
   @AfterClass
-  public static void afterClass() throws SQLException {
+  public static void drop() throws SQLException {
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("DROP view IF EXISTS vendor_code_test_view");
       stmt.execute("DROP TABLE IF EXISTS vendor_code_test");
@@ -482,6 +482,7 @@ public class StatementTest extends BaseTest {
 
   @Test
   public void deadLockInformation() throws SQLException {
+    Assume.assumeTrue(isMariadbServer());
     Statement stmt = sharedConnection.createStatement();
     stmt.execute("insert into deadlock(a) values(0), (1)");
 
@@ -632,6 +633,9 @@ public class StatementTest extends BaseTest {
   @Test
   public void testWarnings() throws SQLException {
     Assume.assumeTrue(isMariadbServer());
+    Assume.assumeTrue(
+        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
+
     Statement stmt = sharedConnection.createStatement();
     stmt.executeQuery("select now() = 1");
     SQLWarning warning = stmt.getWarnings();
