@@ -85,7 +85,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
   @BeforeClass()
   public static void initClass() throws SQLException {
     if (testSingleHost
-        || ((System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null))) {
+        || ((System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv"))))) {
       try (Statement st = sharedConnection.createStatement()) {
         ResultSet rs =
             st.executeQuery(
@@ -124,6 +124,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
       utcDateFormatSimple = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
       utcDateFormatSimple.setTimeZone(utcTimeZone);
+      drop();
       try (Statement stmt = sharedConnection.createStatement()) {
         stmt.execute("CREATE TABLE daylightMysql(tt DATE)");
         stmt.execute(
@@ -151,7 +152,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
   }
 
   @AfterClass
-  public static void afterClass() throws SQLException {
+  public static void drop() throws SQLException {
     try (Statement stmt = sharedConnection.createStatement()) {
       stmt.execute("DROP TABLE IF EXISTS daylightMysql");
       stmt.execute("DROP TABLE IF EXISTS daylight");
@@ -170,7 +171,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
   @AfterClass()
   public static void endClass() {
     if (testSingleHost
-        || ((System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null))) {
+        || ((System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv"))))) {
       TimeZone.setDefault(previousTimeZone);
       if (previousFormatLocale != null) {
         Locale.setDefault(previousFormatLocale);
@@ -217,7 +218,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void testTimeStamp() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     TimeZone.setDefault(parisTimeZone);
     try (Connection connection =
         setConnection("&serverTimezone=Europe/Paris&useServerPrepStmts=true")) {
@@ -251,7 +252,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void testTimeStampUtcNow() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     TimeZone.setDefault(parisTimeZone);
     try (Connection connection = setConnection("&serverTimezone=UTC&useServerPrepStmts=true")) {
       TimeZone.setDefault(parisTimeZone);
@@ -331,7 +332,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void testTimeUtc() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeTrue(doPrecisionTest);
 
     TimeZone.setDefault(parisTimeZone);
@@ -364,7 +365,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void testTimeUtcNow() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     TimeZone.setDefault(parisTimeZone);
     try (Connection connection = setConnection("&serverTimezone=UTC")) {
       setSessionTimeZone(connection, "+00:00");
@@ -384,8 +385,8 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
   public void testTimeOffsetNowUseServer() throws SQLException {
     Assume.assumeTrue(
         System.getenv("AURORA") == null
-            && System.getenv("SKYSQL_HA") == null
-            && System.getenv("SKYSQL") == null);
+            && !"skysql-ha".equals(System.getenv("srv"))
+            && !"skysql".equals(System.getenv("srv")));
     try (Connection connection =
         setConnection("&useLegacyDatetimeCode=false&serverTimezone=+5:00")) {
       setSessionTimeZone(connection, "+5:00");
@@ -404,7 +405,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void testDifferentTimeZoneServer() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     try (Connection connection = setConnection("&serverTimezone=UTC")) {
       setSessionTimeZone(sharedConnection, "+00:00");
       // timestamp timezone to parisTimeZone like server
@@ -420,7 +421,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void testTimeStampOffsetNowUseServer() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     try (Connection connection = setConnection("&serverTimezone=Europe/Paris")) {
       // timestamp timezone to parisTimeZone like server
       Timestamp currentTimeParis = new Timestamp(System.currentTimeMillis());
@@ -444,7 +445,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
   }
 
   private void testDayLight(boolean legacy) throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeTrue(doPrecisionTest);
     Assume.assumeTrue(hasSuperPrivilege("testDayLight") && !sharedIsRewrite());
     TimeZone.setDefault(parisTimeZone);
@@ -810,7 +811,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void testDayLightNotUtC() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeTrue(doPrecisionTest && hasSuperPrivilege("testDayLight") && !sharedIsRewrite());
     TimeZone.setDefault(canadaTimeZone);
     try (Connection connection = setConnection("&serverTimezone=Europe/Paris")) {
@@ -880,7 +881,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void testDayLightWithClientTimeZoneDifferent() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeTrue(doPrecisionTest && !sharedIsRewrite());
     TimeZone.setDefault(parisTimeZone);
     try (Connection connection = setConnection("&serverTimezone=UTC")) {
@@ -933,7 +934,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void testNoMysqlDayLightCompatibility() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeTrue(hasSuperPrivilege("testMysqlDayLightCompatibility"));
     TimeZone.setDefault(parisTimeZone);
     try (Connection connection =
@@ -968,7 +969,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void checkSetLocalDateTimeNoOffset() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeFalse(!isMariadbServer() && strictBeforeVersion(5, 6));
     checkSetLocalDateTime(true, true, "Europe/Paris");
     checkSetLocalDateTime(true, false, "Europe/Paris");
@@ -978,7 +979,7 @@ public class TimezoneDaylightSavingTimeTest extends BaseTest {
 
   @Test
   public void checkSetLocalDateTimeOffset() throws SQLException {
-    Assume.assumeTrue(System.getenv("AURORA") == null && System.getenv("SKYSQL_HA") == null);
+    Assume.assumeTrue(System.getenv("AURORA") == null && !"skysql-ha".equals(System.getenv("srv")));
     Assume.assumeFalse(!isMariadbServer() && strictBeforeVersion(5, 6));
     checkSetLocalDateTime(true, true, "+2:00");
     checkSetLocalDateTime(true, false, "+2:00");
